pub fn hark_forfeit_claim_taproot<G>(
vtxo: &Vtxo<G>,
unlock_hash: UnlockHash,
) -> TaprootSpendInfoExpand description
The taproot for the policy of the output of the hArk forfeit tx
This policy allows the server to spend by revealing the unlock preimage, but still has a timeout to the user after exit delta.